/**
 * 获取指定年月的总天数
 * @method
 * @param {Number} year - 年份
 * @param {Number} month - 月份（1-12）
 * @returns {Number} - 该月总天数
 */
export declare const getDays: (year: number, month: number) => number;
/**
 * 根据日期获取星期几
 * @method
 * @param {Number} year - 年份
 * @param {Number} month - 月份（1-12）
 * @param {Number} day - 日期
 * @returns {Number} - 星期几（0-6，0表示星期日）
 */
export declare const getWeek: (year: number, month: number, day: number) => number;
/**
 * 获取上一个月的年份和月份
 * @method
 * @param {Number} year - 当前年份
 * @param {Number} month - 当前月份（1-12）
 * @returns {Object} - 包含上个月年份和月份的对象
 */
export declare const lastMonth: (year: number, month: number) => {
    year: number;
    month: number;
};
/**
 * 获取下一个月的年份和月份
 * @method
 * @param {Number} year - 当前年份
 * @param {Number} month - 当前月份（1-12）
 * @returns {Object} - 包含下个月年份和月份的对象
 */
export declare const nextMonth: (year: number, month: number) => {
    year: number;
    month: number;
};
/**
 * 日历数据接口定义
 */
interface CalendarData {
    last: {
        year: number;
        month: number;
        start: number;
        end: number;
    };
    current: {
        year: number;
        month: number;
        start: number;
        end: number;
    };
    next: {
        year: number;
        month: number;
        start: number;
        end: number;
    };
}
/**
 * 获取日历数据（包含上月、当月和下月的日期信息）
 * @method
 * @param {Number} year - 年份
 * @param {Number} month - 月份（1-12）
 * @returns {CalendarData | undefined} - 日历数据对象，包含上月、当月和下月的日期信息
 */
export declare const getCalendar: (year: number, month: number) => CalendarData | undefined;
/**
 * 将一维数组转换成 7*N 的二维数组（用于日历表格展示）
 * @method
 * @param {Array<T>} array - 一维数据数组
 * @returns {Array<Array<T>>} - 转换后的7列二维数组
 */
export declare const transformArray: <T>(array: T[]) => T[][];
/**
 * 日期解析结果接口
 */
interface ParsedDate {
    year: number;
    month: number;
    day: number;
    hours: number;
    minutes: number;
    seconds: number;
}
/**
 * 时间转换成年月日时分秒对象
 * @method
 * @param {number | string} time - 时间戳或标准的日期字符串
 * @returns {ParsedDate} - 包含年月日时分秒的对象
 */
export declare const parseDate: (time: number | string) => ParsedDate;
export {};
