/**
 * Copyright (c) 2022 - present TinyVue Authors.
 * Copyright (c) 2022 - present Huawei Cloud Computing Technologies Co., Ltd.
 *
 * Use of this source code is governed by an MIT-style license.
 *
 * THE OPEN SOURCE SOFTWARE IN THIS PRODUCT IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
 * A PARTICULAR PURPOSE. SEE THE APPLICABLE LICENSES FOR MORE DETAILS.
 *
 */
/**
 * 过滤器值类型
 */
interface FilterValue {
    type: string;
    value: any;
    relation?: string;
    text?: string;
}
/**
 * 过滤器对象类型
 */
interface Filters {
    [property: string]: FilterValue;
}
/**
 * 分页参数类型
 */
interface Page {
    currentPage?: number;
    pageSize?: number;
}
/**
 * 排序参数类型
 */
interface Sort {
    property?: string;
    order?: string;
}
/**
 * 数据源参数类型
 */
interface Source {
    url: string;
    type?: string;
    method?: string;
    data?: Record<string, any>;
    beforeRequest?: (config: any, args?: any) => void;
    afterRequest?: (data: any) => void;
    success?: (data: any) => void;
    hideErr?: boolean;
    [key: string]: any;
}
/**
 * API 参数类型
 */
interface Api {
    name: string;
    data?: Record<string, any>;
}
/**
 * 数据集参数类型
 */
interface Dataset {
    source?: Source;
    value?: any[];
    api?: Api;
    service?: any;
}
/**
 * 数据集参数类型（完整）
 */
interface DatasetOptions {
    dataset?: Dataset | any[];
    service?: any;
    tree?: {
        key?: string;
        parentKey?: string;
    };
}
/**
 * 请求参数类型
 */
interface RequestArgs {
    page?: Page;
    sort?: Sort;
    filters?: Filters;
    [key: string]: any;
}
/**
 * 获取数据集数据，支持多种数据源方式：
 * 1. 直接数组数据
 * 2. 通过 source 配置的网络请求
 * 3. 通过 api 配置的服务方法调用
 *
 * @param {DatasetOptions} param0 - 数据集配置选项
 * @param {RequestArgs} args - 请求参数
 * @returns {Promise<any>} - 返回处理后的数据承诺
 */
export declare const getDataset: ({ dataset, service, tree }: DatasetOptions, args?: RequestArgs) => Promise<any>;
export {};
